%define libname libdwarves
%define libver 1
 
Summary: Debugging Information Manipulation Tools (pahole & friends)
Name:    dwarves
Version: 1.25
Release: 3%{?dist}
License: GPLv2
URL:     http://acmel.wordpress.com
Source0: http://fedorapeople.org/~acme/dwarves/%{name}-%{version}.tar.xz

BuildRequires: gcc cmake zlib-devel elfutils-devel
Requires: %{libname}%{libver} = %{version}-%{release}
 
%description
dwarves is a set of tools that use the debugging information inserted in ELF binaries by compilers such as
GCC, used by well known debuggers such as GDB, and more recent ones such as systemtap.
 
Utilities in the dwarves suite include pahole, that can be used to find alignment holes in structs and
classes in languages such as C, C++, but not limited to these.
 
It also extracts other information such as CPU cacheline alignment, helping pack those structures to
achieve more cache hits.
 
These tools can also be used to encode and read the BTF type information format used with the Linux kernel
bpf syscall, using 'pahole -J' and 'pahole -F btf'.
 
A diff like tool, codiff can be used to compare the effects changes in source code generate on the resulting binaries.
 
Another tool is pfunct, that can be used to find all sorts of information about functions, inlines,
decisions made by the compiler about inlining, etc.
 
One example of pfunct usage is in the fullcircle tool, a shell that drivers pfunct to generate compileable
code out of a .o file and then build it using gcc, with the same compiler flags, and then use codiff to
make sure the original .o file and the new one generated from debug info produces the same debug info.
 
Pahole also can be used to use all this type information to pretty print raw data according to command
line directions.
 
Headers can have its data format described from debugging info and offsets from it can be used to further
format a number of records.
 
The btfdiff utility compares the output of pahole from BTF and DWARF to make sure they produce the same results.
 
%package -n %{libname}%{libver}
Summary: Debugging information  processing library
 
%description -n %{libname}%{libver}
Debugging information processing library.
 
%package -n %{libname}%{libver}-devel
Summary: Debugging information library development files
Requires: %{libname}%{libver} = %{version}-%{release}
 
%description -n %{libname}%{libver}-devel
Debugging information processing library development files.
 
%prep
%autosetup -n %{name}-%{version} -p1
 
%build
%cmake -DCMAKE_BUILD_TYPE=Release .
%cmake_build

%install
rm -Rf %{buildroot}
%cmake_install
 
%files
%doc README.ctracer README.btf changes-v1.23 NEWS
%{_bindir}/*
%dir %{_datadir}/dwarves/
%dir %{_datadir}/dwarves/runtime/
%dir %{_datadir}/dwarves/runtime/python/
%defattr(0644,root,root,0755)
%{_datadir}/dwarves/runtime/Makefile
%{_datadir}/dwarves/runtime/linux.blacklist.cu
%{_datadir}/dwarves/runtime/ctracer_relay.c
%{_datadir}/dwarves/runtime/ctracer_relay.h
%attr(0755,root,root) %{_datadir}/dwarves/runtime/python/ostra.py*
%{_mandir}/man1/pahole.1*
%exclude %{_bindir}/dtagnames
%exclude %{_bindir}/prefcnt
 
%files -n %{libname}%{libver}
%{_libdir}/%{libname}.so.*
%{_libdir}/%{libname}_emit.so.*
%{_libdir}/%{libname}_reorganize.so.*
 
%files -n %{libname}%{libver}-devel
%doc MANIFEST README
%{_includedir}/dwarves/*.h
%{_libdir}/%{libname}.so
%{_libdir}/%{libname}_emit.so
%{_libdir}/%{libname}_reorganize.so
 
%changelog
* Wed Jan 17 2024 Rebuild Robot <rebot@opencloudos.org> - 1.25-3
- Rebuilt for elfutils

* Fri Sep 08 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.25-2
- Rebuilt for OpenCloudOS Stream 23.09

* Mon Jul 10 2023 Shuo Wang <abushwang@tencent.com> - 1.25-1
- update to 1.25

* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.23-4
- Rebuilt for OpenCloudOS Stream 23.05

* Fri Mar 31 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.23-3
- Rebuilt for OpenCloudOS Stream 23

* Wed Mar 15 2023 Shuo Wang <abushwang@tencent.com> - 1.23-2
- do not provides dtagnames prefcnt for its fata logic

* Tue Jan 31 2023 Shuo Wang <abushwang@tencent.com> - 1.23-1
- initial build 
